sample_grid_soa

Function sample_grid_soa 

pub fn sample_grid_soa<S: DecodingStrategy>(
    img: &ImageView<'_>,
    arena: &Bump,
    corners: &[Point2f],
    homography: &Matrix3x3,
    decoder: &(impl TagDecoder + ?Sized),
) -> Option<S::Code>
Sample the bit grid using Structure of Arrays (SoA) data.

Panics

Panics if the number of sample points exceeds MAX_BIT_COUNT.