Homography

Struct Homography 

pub struct Homography {
    pub h: SMatrix<f64, 3, 3>,
}
A 3x3 Homography matrix.

Fields

h: SMatrix<f64, 3, 3>

The 3x3 homography matrix.

Implementations

Source

impl Homography

pub fn to_dda(&self, u0: f64, v0: f64, du: f64, dv: f64) -> HomographyDda

Convert the homography into a DDA state for a grid with step size (du, dv). Initial state is computed at (u0, v0) in canonical tag space.

pub fn from_pairs(src: &[[f64; 2]; 4], dst: &[[f64; 2]; 4]) -> Option<Self>

Compute homography from 4 source points to 4 destination points using DLT. Points are [x, y]. Compute homography from 4 source points to 4 destination points using DLT. Points are [x, y].

pub fn square_to_quad(dst: &[[f64; 2]; 4]) -> Option<Self>

Optimized homography computation from canonical unit square to a quad. Source points are assumed to be: [(-1,-1), (1,-1), (1,1), (-1,1)].

pub fn project(&self, p: [f64; 2]) -> [f64; 2]

Project a point using the homography.