pub struct HomographyDda {
pub nx: f64,
pub ny: f64,
pub d: f64,
pub dnx_du: f64,
pub dny_du: f64,
pub dd_du: f64,
pub dnx_dv: f64,
pub dny_dv: f64,
pub dd_dv: f64,
}Expand description
A Digital Differential Analyzer (DDA) for incremental homography projection.
This avoids expensive matrix multiplications by using discrete partial derivatives when stepping through a uniform grid in tag space.
Fields
nx: f64Current numerator for X coordinate.
ny: f64Current numerator for Y coordinate.
d: f64Current denominator (perspective divide).
dnx_du: f64Partial derivative of nx with respect to u.
dny_du: f64Partial derivative of ny with respect to u.
dd_du: f64Partial derivative of d with respect to u.
dnx_dv: f64Partial derivative of nx with respect to v.
dny_dv: f64Partial derivative of ny with respect to v.
dd_dv: f64Partial derivative of d with respect to v.