RoiCache

Enum RoiCache 

pub enum RoiCache<'a> {
    Stack {
        data: [u8; 1024],
        min_x: usize,
        min_y: usize,
        width: usize,
        height: usize,
    },
    Arena {
        data: &'a [u8],
        min_x: usize,
        min_y: usize,
        width: usize,
        height: usize,
    },
}
A cache for a small region of the image to improve L1 cache hits during sampling.

Variants



Stack

Small ROI stored on the stack.

Fields

data: [u8; 1024]

The cached pixel data.

min_x: usize

The bounding box of the ROI in the original image.

min_y: usize

The bounding box of the ROI in the original image.

width: usize

Width of the ROI.

height: usize

Height of the ROI.



Arena

Larger ROI stored in the arena.

Fields

data: &'a [u8]

The cached pixel data.

min_x: usize

The bounding box of the ROI in the original image.

min_y: usize

The bounding box of the ROI in the original image.

width: usize

Width of the ROI.

height: usize

Height of the ROI.

Implementations

Source

impl<'a> RoiCache<'a>

pub fn new( img: &ImageView<'_>, arena: &'a Bump, min_x: usize, min_y: usize, max_x: usize, max_y: usize, ) -> Self

Create a new ROI cache by copying a region from the image.

If the region fits in 1024 bytes, it is stored on the stack. Otherwise, it is allocated from the provided arena.

pub fn get(&self, x: usize, y: usize) -> u8

Get a pixel from the cache using global coordinates.