Zero-cost camera distortion model trait and implementations. Zero-cost camera distortion model abstractions.
This module defines the CameraModel trait and its three concrete implementations:
PinholeModel: Ideal pinhole (no distortion).IS_RECTIFIED = truecauses the compiler to eliminate all distortion branches in the hot path.- [
BrownConradyModel]: Standard polynomial radial + tangential distortion (OpenCV convention). - [
KannalaBrandtModel]: Equidistant fisheye projection model.
All models operate on normalized image coordinates (xn, yn) — i.e., after
dividing pixel coordinates by the focal lengths and subtracting the principal point:
xn = (px - cx) / fx, yn = (py - cy) / fy.
Structs
- Pinhole
Model - Ideal pinhole camera model (no distortion).
Traits
- Camera
Model - A compile-time abstraction over camera distortion models.