pub fn sample_grid_soa_precomputed<S: DecodingStrategy>(
img: &ImageView<'_>,
roi: &RoiCache<'_>,
homography: &Matrix3x3,
decoder: &(impl TagDecoder + ?Sized),
) -> Option<S::Code>Expand description
Sample the bit grid using Structure of Arrays (SoA) data and a precomputed ROI cache.
Panics
Panics if the number of sample points exceeds MAX_BIT_COUNT.