pub struct Detector { /* private fields */ }Expand description
The primary entry point for the Locus perception library.
Detector encapsulates the entire detection pipeline.
Implementations
Sourceimpl Detector
impl Detector
Sourcepub fn builder() -> DetectorBuilder
pub fn builder() -> DetectorBuilder
Returns a builder to configure a new detector.
Sourcepub fn with_config(config: DetectorConfig) -> Self
pub fn with_config(config: DetectorConfig) -> Self
Create a detector with custom pipeline configuration.
Sourcepub fn state(&self) -> &DetectorState
pub fn state(&self) -> &DetectorState
Access the internal state (for advanced inspection or FFI).
Sourcepub fn set_families(&mut self, families: &[TagFamily])
pub fn set_families(&mut self, families: &[TagFamily])
Clear all decoders and set new ones based on tag families.
Sourcepub fn detect(
&mut self,
img: &ImageView<'_>,
intrinsics: Option<&CameraIntrinsics>,
tag_size: Option<f64>,
pose_mode: PoseEstimationMode,
debug_telemetry: bool,
) -> Result<DetectionBatchView<'_>, DetectorError>
pub fn detect( &mut self, img: &ImageView<'_>, intrinsics: Option<&CameraIntrinsics>, tag_size: Option<f64>, pose_mode: PoseEstimationMode, debug_telemetry: bool, ) -> Result<DetectionBatchView<'_>, DetectorError>
Detect tags in the provided image.
This method is the main execution pipeline.
Errors
Returns DetectorError if the input image cannot be decimated, upscaled,
or if an intermediate image view cannot be constructed.
Sourcepub fn config(&self) -> &DetectorConfig
pub fn config(&self) -> &DetectorConfig
Get the current detector configuration.