Gradient computation for edge refinement. Gradient computation for edge-based quad detection.
Structs
- Gradient
- Gradient data for a single pixel.
- Line
Segment - A detected line segment.
Functions
- compute_
sobel - Compute Sobel gradients for the entire image. Returns a flat array of Gradient structs.
- extract_
line_ segments - Extract line segments from gradient image using a simplified LSD approach. This is a greedy region-growing algorithm on gradient direction.
- find_
first_ quad_ from_ segments - Find quads by grouping 4 line segments that form a closed quadrilateral.
- fit_
quad_ from_ component - Fit a quad from a small component using on-demand gradient computation.
- fit_
quad_ from_ gradients - Fit a quad from boundary pixels using gradient direction clustering.